django-htpayway
=======================

Django app for [HT PayWay][payway] (croatian only web) payment gateway
integration.


[payway]: https://www.hrvatskitelekom.hr/poslovni/ict/poslovna-rjesenja/web-shop#payway
